import { CustomEventMap } from '@genesislcap/foundation-events';
import { AbstractStore, AbstractStoreRoot, Store, StoreRoot, StoreRootEventDetailMap } from '../store';
import { ReportService, SubService } from './services';
import type { ReportEntity, SubEntity } from './types';
/**
 * @internal
 */
export type SubStoreEventMap = {
    'x-changed': string;
    'y-changed': number;
    'z-changed': number;
    'select-sub-entity': SubEntity;
    'remove-sub-entity': SubEntity;
};
type SubStoreInternalEventMap = {
    'sub-load': string;
    'sub-load-error': Error;
    'sub-load-success': SubEntity[];
};
declare global {
    interface HTMLElementEventMap extends CustomEventMap<SubStoreEventMap> {
    }
}
/**
 * SubStore.
 *
 * @remarks
 * These stores demo common usage patterns.
 *
 * @internal
 */
export interface SubStore extends Store {
    readonly x: string;
    readonly y: number;
    readonly z: number;
    readonly lastChangedProperty: string;
    readonly derived: number;
    readonly entities: SubEntity[];
    readonly selectedEntity: SubEntity;
    onXChanged(event: CustomEvent<string>): void;
    onYChanged(event: CustomEvent<number>): void;
    onZChanged(event: CustomEvent<number>): void;
    onSelectSubEntity(event: CustomEvent<SubEntity>): void;
    onRemoveSubEntity(event: CustomEvent<SubEntity>): void;
    toEntity(): SubEntity;
}
/**
 * @internal
 */
export declare class DefaultSubStore extends AbstractStore<SubStore, SubStoreEventMap, SubStoreInternalEventMap> implements SubStore {
    readonly service: SubService;
    x: string;
    y: number;
    z: number;
    lastChangedProperty: string;
    entities: SubEntity[];
    selectedEntity: SubEntity;
    constructor(service: SubService);
    onXChanged: EventListener;
    onYChanged: EventListener;
    onZChanged: EventListener;
    onSelectSubEntity: EventListener;
    onRemoveSubEntity: EventListener;
    /**
     * Does not need any special code as it's computing based on properties that are already observable.
     */
    get derived(): number;
    /**
     * Some serialised store state.
     */
    toEntity: () => {
        label: string;
        quantity: number;
    };
}
/**
 * Registering as `transient` with the DI directly instead of via `registerStore` given test suite create/destroy cycle.
 * Normally store fragments are singletons, use `registerStore` in 99% of cases.
 * @internal
 */
export declare const SubStore: import("@microsoft/fast-foundation").InterfaceSymbol<SubStore>;
/**
 * @internal
 */
export type TestStoreEventDetailMap = StoreRootEventDetailMap & {
    'a-changed': string;
    'b-changed': number;
    'c-changed': number;
};
type TestStoreInternalEventMap = {
    'post-report': ReportEntity;
};
declare global {
    interface HTMLElementEventMap extends CustomEventMap<TestStoreEventDetailMap> {
    }
}
/**
 * TestStore.
 *
 * @remarks
 * These stores demo common usage patterns.
 *
 * @internal
 */
export interface TestStore extends StoreRoot {
    readonly a: string;
    readonly b: number;
    readonly c: number;
    readonly volatileDerived: number;
    readonly classNames: string;
    readonly subStore: SubStore;
    onAChanged(event: CustomEvent<string>): void;
    onBChanged(event: CustomEvent<number>): void;
    onCChanged(event: CustomEvent<number>): void;
}
/**
 * @internal
 */
export declare class DefaultTestStore extends AbstractStoreRoot<TestStore, TestStoreEventDetailMap, TestStoreInternalEventMap> implements TestStore {
    readonly subStore: SubStore;
    readonly service: ReportService;
    a: string;
    b: number;
    c: number;
    constructor(subStore: SubStore, service: ReportService);
    onAChanged: EventListener;
    onBChanged: EventListener;
    onCChanged: EventListener;
    /**
     * Marked as volatile as it contains branching code paths
     */
    get volatileDerived(): number;
    /**
     * Generates css classnames based on store state
     */
    get classNames(): string;
}
/**
 * Registering as `transient` with the DI directly instead of via `registerStore` given test suite create/destroy cycle.
 * Normally store fragments are singletons, use `registerStore` in 99% of cases.
 * @internal
 */
export declare const TestStore: import("@microsoft/fast-foundation").InterfaceSymbol<TestStore>;
export {};
//# sourceMappingURL=store.d.ts.map