import { __decorate } from "tslib";
import { EventEmitter } from '@genesislcap/foundation-events';
import { children, customElement, elements, FASTElement, html, observable, ref, repeat } from '@microsoft/fast-element';
import { ReportService, SubService } from './services';
import { TestStore } from './store';
/**
 * @internal
 */
let TestChildElement = class TestChildElement extends EventEmitter(FASTElement) {
};
__decorate([
    observable
], TestChildElement.prototype, "subStore", void 0);
__decorate([
    observable
], TestChildElement.prototype, "entityNodes", void 0);
TestChildElement = __decorate([
    customElement({
        name: 'store-test-child-element',
        /**
         * Template contains some fake/non-registered tags to aid test assertions.
         */
        template: html `
    <template>
      <x-value>${(x) => x.subStore.x}</x-value>
      <y-value>${(x) => x.subStore.y}</y-value>
      <z-value>${(x) => x.subStore.z}</z-value>
      <last-changed-value>${(x) => x.subStore.lastChangedProperty}</last-changed-value>
      <ul ${children({ property: 'entityNodes', filter: elements('li') })}>
        ${repeat((x) => x.subStore.entities, html `
          <li>${(x, c) => c.index}: ${(x) => x.label}</li>
        `, { positioning: true })}
        )}
      </ul>
    </template>
  `,
    })
], TestChildElement);
export { TestChildElement };
/**
 * @internal
 */
let TestElement = class TestElement extends EventEmitter(FASTElement) {
    /**
     * @public
     */
    connectedCallback() {
        super.connectedCallback();
        this.addEventListeners();
        this.readyStore();
    }
    /**
     * @public
     */
    disconnectedCallback() {
        super.disconnectedCallback();
        this.removeEventListeners();
        this.disconnectStore();
    }
    /**
     * @internal
     */
    addEventListeners() {
        this.addEventListener('store-connected', this.testStore.onConnected);
    }
    /**
     * @internal
     */
    removeEventListeners() {
        this.removeEventListener('store-connected', this.testStore.onConnected);
    }
    /**
     * @internal
     */
    readyStore() {
        this.$emit('store-connected', this);
        this.$emit('store-ready', true);
    }
    /**
     * @internal
     */
    disconnectStore() {
        this.$emit('store-disconnected');
    }
};
__decorate([
    TestStore
], TestElement.prototype, "testStore", void 0);
__decorate([
    ReportService
], TestElement.prototype, "reportService", void 0);
__decorate([
    SubService
], TestElement.prototype, "subService", void 0);
__decorate([
    observable
], TestElement.prototype, "child", void 0);
TestElement = __decorate([
    customElement({
        name: 'store-test-element',
        /**
         * Template contains some fake/non-registered tags to aid test assertions.
         */
        template: html `
    <template>
      <store-test-child-element
        ${ref('child')}
        class=${(x) => x.testStore.classNames}
        :subStore=${(x) => x.testStore.subStore}
      ></store-test-child-element>
      <a-value>${(x) => x.testStore.a}</a-value>
      <b-value>${(x) => x.testStore.b}</b-value>
      <c-value>${(x) => x.testStore.c}</c-value>
    </template>
  `,
    })
], TestElement);
export { TestElement };
